{*************************+********************************}
{*                                                        *}
{*   Nazov: INI file reader/writer                        *}
{*   Datum:  5.10.2001                                    *}
{*   Start:  3.10.2001                                    *}
{*   Jazyk: Turbo Pascal 7.0                              *}
{*   Autor: Milsoft                                       *}
{*   Typ:   Unit                                          *}
{*                                                        *}
{**********************************************************}

{$F-,O-,A+,G+,R+,S-,I-,Q+,V+,B-,X+,T+,P-,D-,L-,Y-,N-,E-}

unit IniFile;

interface

const
  INI_OK               = 0;
  INI_EndFile          = 1;
  INI_IllegalChar      = 2;
  INI_IllegalBlockName = 3;
  INI_ValueNotFound    = 4;
type
  string31  = string[31];
  string127 = string[127];
var
  INIerror: integer;
  INIblock: string31;

procedure ResetINI(name: string127);
procedure ReWriteINI(name: string127);
procedure CloseINI;
function EndOfINI: boolean;
procedure ReadSeqValue(var block,name,value: string31);
procedure WriteBlock(block: string31);
procedure WriteBlockRem(block: string31; rem: string);
procedure WriteValue(name,value: string31);
procedure WriteValueRem(name,value: string31; rem: string);

implementation

uses utility;
var
  f: text;

procedure CheckStr(var s: string);
var
  i: byte;
begin
  i := pos(';',s);
  if i > 0 then delete(s,i,length(s) - i + 1);
  i := length(s);
  while (i > 0) and (s[i] in [' ',#8]) do dec(i);
  delete(s,i + 1,length(s) - i);
  if i > 0 then
    begin
      i := 0;
      while s[i + 1] in [' ',#8] do inc(i);
      delete(s,1,i);
    end;
end;

procedure ResetINI(name: string127);
begin
  iniblock := '';
  assign(f,name);
  reset(f);
  inierror := ioresult;
end;

procedure ReWriteINI(name: string127);
begin
  iniblock := '';
  assign(f,name);
  rewrite(f);
  inierror := ioresult;
end;

procedure CloseINI;
begin
  close(f);
  inierror := ioresult;
end;

function EndOfINI: boolean;
begin
  endofini := eof(f);
end;

procedure ReadSeqValue(var block,name,value: string31);
var
  s: string;
  i: byte;
begin
  inierror := ini_ok;
  block := '';
  name := '';
  value := '';
  while not eof(f) do
    begin
      readln(f,s);
      checkstr(s);
      if s = '' then continue;
      if s[1] = '[' then
        begin
          if s[length(s)] = ']' then
            begin
              block := copy(s,2,length(s) - 2);
              iniblock := block;
            end
          else
            begin
              inierror := ini_illegalblockname;
              exit;
            end;
        end
      else
        begin
          i := pos('=',s);
          if i > 0 then
            begin
              block := iniblock;
              name := copy(s,1,i - 1);
              value := copy(s,i + 1,length(s) - i);
            end
          else
            inierror := ini_valuenotfound;
          exit;
        end;
    end;
end;

procedure WriteBlock(block: string31);
begin
  if iniblock <> '' then writeln(f);
  writeln(f,'[',block,']');
  iniblock := block;
end;

procedure WriteBlockRem(block: string31; rem: string);
var
  i: byte;
begin
  if iniblock <> '' then writeln(f);
  write(f,'[',block,']');
  for i := 1 to 61 - length(block) do write(f,' ');
  writeln(f,';',rem);
  iniblock := block;
end;

procedure WriteValue(name,value: string31);
begin
  writeln(f,name,'=',value);
end;

procedure WriteValueRem(name,value: string31; rem: string);
var
  i: byte;
begin
  write(f,name,'=',value);
  for i := 1 to 62 - length(name) - length(value) do write(f,' ');
  writeln(f,';',rem);
end;

end.
